""" Schemas for the action request body. Woot, woot. """

from __future__ import annotations

from pydantic.dataclasses import dataclass, Field
from enum import Enum
from typing import Any, Dict, List, Optional, Union


@dataclass
class RequestError:
    field: Optional[str] = None
    message: Optional[str] = None
    code: Optional[str] = None


@dataclass
class GenericId:
    id: Optional[float] = None


@dataclass
class CannedResponse:
    id: Optional[int] = None
    content: Optional[str] = None
    short_code: Optional[str] = None
    account_id: Optional[int] = None


@dataclass
class CustomAttribute:
    id: Optional[int] = None
    attribute_display_name: Optional[str] = None
    attribute_display_type: Optional[str] = None
    attribute_description: Optional[str] = None
    attribute_key: Optional[str] = None
    attribute_values: Optional[str] = None
    default_value: Optional[str] = None
    attribute_model: Optional[str] = None
    account_id: Optional[int] = None


class EventName(Enum):
    conversation_created = "conversation_created"
    conversation_updated = "conversation_updated"
    message_created = "message_created"


@dataclass
class AutomationRule:
    event_name: Optional[EventName] = None
    name: Optional[str] = None
    description: Optional[str] = None
    active: Optional[bool] = None
    actions: Optional[List[Dict[str, Any]]] = None
    conditions: Optional[List[Dict[str, Any]]] = None
    account_id: Optional[int] = None


class Status(Enum):
    open = "open"
    resolved = "resolved"
    pending = "pending"


class ContentType(Enum):
    text = "text"
    input_select = "input_select"
    cards = "cards"
    form = "form"


class MessageType(Enum):
    incoming = "incoming"
    outgoing = "outgoing"
    activity = "activity"
    template = "template"


@dataclass
class Message:
    content: Optional[str] = None
    content_type: Optional[ContentType] = None
    content_attributes: Optional[Dict[str, Any]] = None
    message_type: Optional[MessageType] = None
    created_at: Optional[int] = None
    private: Optional[bool] = None
    attachment: Optional[Dict[str, Any]] = None
    sender: Optional[Dict[str, Any]] = None
    conversation_id: Optional[float] = None


class Role(Enum):
    agent = "agent"
    administrator = "administrator"


class AvailabilityStatus(Enum):
    available = "available"
    busy = "busy"
    offline = "offline"


@dataclass
class Agent:
    id: Optional[int] = None
    uid: Optional[str] = None
    name: Optional[str] = None
    available_name: Optional[str] = None
    display_name: Optional[str] = None
    email: Optional[str] = None
    account_id: Optional[int] = None
    role: Optional[Role] = None
    confirmed: Optional[bool] = None
    availability_status: Optional[AvailabilityStatus] = None
    auto_offline: Optional[bool] = None
    custom_attributes: Optional[Dict[str, Any]] = None


@dataclass
class Inbox:
    id: Optional[float] = None
    name: Optional[str] = None
    website_url: Optional[str] = None
    channel_type: Optional[str] = None
    avatar_url: Optional[str] = None
    widget_color: Optional[str] = None
    website_token: Optional[str] = None
    enable_auto_assignment: Optional[bool] = None
    web_widget_script: Optional[str] = None
    welcome_title: Optional[str] = None
    welcome_tagline: Optional[str] = None
    greeting_enabled: Optional[bool] = None
    greeting_message: Optional[str] = None


@dataclass
class AgentBot:
    id: Optional[float] = None
    name: Optional[str] = None
    description: Optional[str] = None
    account_id: Optional[float] = None
    outgoing_url: Optional[str] = None


@dataclass
class ContactInboxes:
    source_id: Optional[str] = None
    inbox: Optional[Inbox] = None


@dataclass
class ContactableInboxes:
    source_id: Optional[str] = None
    inbox: Optional[Inbox] = None


class Type(Enum):
    conversation = "conversation"
    contact = "contact"
    report = "report"


@dataclass
class CustomFilter:
    id: Optional[float] = None
    name: Optional[str] = None
    type: Optional[Type] = None
    query: Optional[Dict[str, Any]] = None
    created_at: Optional[str] = None
    updated_at: Optional[str] = None


class Subscription(Enum):
    conversation_created = "conversation_created"
    conversation_status_changed = "conversation_status_changed"
    conversation_updated = "conversation_updated"
    message_created = "message_created"
    message_updated = "message_updated"
    webwidget_triggered = "webwidget_triggered"


@dataclass
class Webhook:
    id: Optional[float] = None
    url: Optional[str] = None
    subscriptions: Optional[List[Subscription]] = None
    account_id: Optional[float] = None


class Role2(Enum):
    administrator = "administrator"
    agent = "agent"


@dataclass
class Account:
    id: Optional[float] = None
    name: Optional[str] = None
    role: Optional[Role2] = None


@dataclass
class PlatformAccount:
    id: Optional[float] = None
    name: Optional[str] = None


@dataclass
class Team:
    id: Optional[float] = None
    name: Optional[str] = None
    description: Optional[str] = None
    allow_auto_assign: Optional[bool] = None
    account_id: Optional[float] = None
    is_member: Optional[bool] = None


@dataclass
class IntegrationsApp:
    id: Optional[str] = None
    name: Optional[str] = None
    description: Optional[str] = None
    hook_type: Optional[str] = None
    enabled: Optional[bool] = None
    allow_multiple_hooks: Optional[bool] = None
    hooks: Optional[List[Dict[str, Any]]] = None


@dataclass
class IntegrationsHook:
    id: Optional[str] = None
    app_id: Optional[str] = None
    inbox_id: Optional[str] = None
    account_id: Optional[str] = None
    status: Optional[bool] = None
    hook_type: Optional[bool] = None
    settings: Optional[Dict[str, Any]] = None


@dataclass
class PublicContact:
    id: Optional[int] = None
    source_id: Optional[str] = None
    name: Optional[str] = None
    email: Optional[str] = None
    pubsub_token: Optional[str] = None


@dataclass
class PublicConversation:
    id: Optional[int] = None
    inbox_id: Optional[str] = None
    messages: Optional[List[Message]] = None
    contact: Optional[Dict[str, Any]] = None


@dataclass
class PublicMessage:
    id: Optional[str] = None
    content: Optional[str] = None
    message_type: Optional[str] = None
    content_type: Optional[str] = None
    content_attributes: Optional[str] = None
    created_at: Optional[str] = None
    conversation_id: Optional[str] = None
    attachments: Optional[List[Dict[str, Any]]] = None
    sender: Optional[Dict[str, Any]] = None


@dataclass
class AccountCreateUpdatePayload:
    name: Optional[str] = None


@dataclass
class AgentBotCreateUpdatePayload:
    name: Optional[str] = None
    description: Optional[str] = None
    outgoing_url: Optional[str] = None


@dataclass
class UserCreateUpdatePayload:
    name: Optional[str] = None
    email: Optional[str] = None
    password: Optional[str] = None
    custom_attributes: Optional[Dict[str, Any]] = None


@dataclass
class CannedResponseCreateUpdatePayload:
    content: Optional[str] = None
    short_code: Optional[str] = None


@dataclass
class CustomAttributeCreateUpdatePayload:
    attribute_display_name: Optional[str] = None
    attribute_display_type: Optional[int] = None
    attribute_description: Optional[str] = None
    attribute_key: Optional[str] = None
    attribute_values: Optional[List[str]] = None
    attribute_model: Optional[int] = None


@dataclass
class ContactCreate:
    inbox_id: float
    name: Optional[str] = None
    email: Optional[str] = None
    phone_number: Optional[str] = None
    avatar: Optional[bytes] = None
    avatar_url: Optional[str] = None
    identifier: Optional[str] = None
    custom_attributes: Optional[Dict[str, Any]] = None


@dataclass
class ContactUpdate:
    name: Optional[str] = None
    email: Optional[str] = None
    phone_number: Optional[str] = None
    avatar: Optional[bytes] = None
    avatar_url: Optional[str] = None
    identifier: Optional[str] = None
    custom_attributes: Optional[Dict[str, Any]] = None


class MessageType1(Enum):
    outgoing = "outgoing"
    incoming = "incoming"


class ContentType1(Enum):
    input_email = "input_email"
    cards = "cards"
    input_select = "input_select"
    form = "form"
    article = "article"


@dataclass
class ConversationMessageCreate:
    content: str
    message_type: Optional[MessageType1] = None
    private: Optional[bool] = None
    content_type: Optional[ContentType1] = None
    content_attributes: Optional[Dict[str, Any]] = None


@dataclass
class ConversationMessageAttachmentCreate:
    content: str
    files: Optional[Dict[str, Union[str, Any]]] = None
    message_type: Optional[MessageType1] = None
    file_type: Optional[str] = None


@dataclass
class TeamCreateUpdatePayload:
    name: Optional[str] = None
    description: Optional[str] = None
    allow_auto_assign: Optional[bool] = None


@dataclass
class CustomFilterCreateUpdatePayload:
    name: Optional[str] = None
    type: Optional[Type] = None
    query: Optional[Dict[str, Any]] = None


@dataclass
class WebhookCreateUpdatePayload:
    url: Optional[str] = None
    subscriptions: Optional[List[Subscription]] = None


@dataclass
class IntegrationsHookCreatePayload:
    app_id: Optional[str] = None
    inbox_id: Optional[str] = None
    settings: Optional[Dict[str, Any]] = None


@dataclass
class IntegrationsHookUpdatePayload:
    settings: Optional[Dict[str, Any]] = None


@dataclass
class AutomationRuleCreateUpdatePayload:
    name: Optional[str] = None
    description: Optional[str] = None
    event_name: Optional[EventName] = None
    active: Optional[bool] = None
    actions: Optional[List[Dict[str, Any]]] = None
    conditions: Optional[List[Dict[str, Any]]] = None


@dataclass
class PublicContactCreateUpdatePayload:
    identifier: Optional[str] = None
    identifier_hash: Optional[str] = None
    email: Optional[str] = None
    name: Optional[str] = None
    phone_number: Optional[str] = None
    avatar_url: Optional[str] = None
    custom_attributes: Optional[Dict[str, Any]] = None


@dataclass
class PublicMessageCreatePayload:
    content: Optional[str] = None
    echo_id: Optional[str] = None


@dataclass
class PublicMessageUpdatePayload:
    submitted_values: Optional[Dict[str, Any]] = None


class AvailabilityStatus1(Enum):
    online = "online"
    offline = "offline"


@dataclass
class Sender:
    id: Optional[float] = None
    name: Optional[str] = None
    thumbnail: Optional[str] = None
    channel: Optional[str] = None


@dataclass
class Meta1:
    mine_count: Optional[float] = None
    unassigned_count: Optional[float] = None
    assigned_count: Optional[float] = None
    all_count: Optional[float] = None


class CurrentStatus(Enum):
    open = "open"
    resolved = "resolved"


@dataclass
class Payload:
    success: Optional[bool] = None
    current_status: Optional[CurrentStatus] = None
    conversation_id: Optional[float] = None


@dataclass
class ConversationStatusToggle:
    meta: Optional[Dict[str, Any]] = None
    payload: Optional[Payload] = None


@dataclass
class ConversationLabels:
    payload: Optional[List[str]] = None


@dataclass
class ExtendedMessage(GenericId, Message):
    source_id: Optional[float] = None
    sender: Optional[Dict[str, Any]] = None


@dataclass
class Previous:
    avg_first_response_time: Optional[str] = None
    avg_resolution_time: Optional[str] = None
    conversations_count: Optional[float] = None
    incoming_messages_count: Optional[float] = None
    outgoing_messages_count: Optional[float] = None
    resolutions_count: Optional[float] = None


@dataclass
class AccountSummary:
    avg_first_response_time: Optional[str] = None
    avg_resolution_time: Optional[str] = None
    conversations_count: Optional[float] = None
    incoming_messages_count: Optional[float] = None
    outgoing_messages_count: Optional[float] = None
    resolutions_count: Optional[float] = None
    previous: Optional[Previous] = None


@dataclass
class Metric:
    open: Optional[float] = None
    unattended: Optional[float] = None


@dataclass
class AgentConversationMetrics:
    id: Optional[float] = None
    name: Optional[str] = None
    email: Optional[str] = None
    thumbnail: Optional[str] = None
    availability: Optional[str] = None
    metric: Optional[Metric] = None


@dataclass
class PlatformApiV1AccountsAccountIdAccountUsersGetResponse:
    account_id: Optional[int] = None
    user_id: Optional[int] = None
    role: Optional[str] = None


@dataclass
class PlatformApiV1AccountsAccountIdAccountUsersPostRequest:
    user_id: int
    role: str


@dataclass
class PlatformApiV1AccountsAccountIdAccountUsersPostResponse:
    account_id: Optional[int] = None
    user_id: Optional[int] = None
    role: Optional[str] = None


@dataclass
class PlatformApiV1AccountsAccountIdAccountUsersDeleteRequest:
    user_id: int


@dataclass
class PlatformApiV1UsersIdLoginGetResponse:
    url: Optional[str] = None


class Role3(Enum):
    agent = "agent"
    administrator = "administrator"


class AvailabilityStatus2(Enum):
    available = "available"
    busy = "busy"
    offline = "offline"


@dataclass
class ApiV1AccountsAccountIdAgentsPostRequest:
    name: str
    email: str
    role: Role3
    availability_status: Optional[AvailabilityStatus2] = None
    auto_offline: Optional[bool] = None


class Availability(Enum):
    available = "available"
    busy = "busy"
    offline = "offline"


@dataclass
class ApiV1AccountsAccountIdAgentsIdPatchRequest:
    role: Role3
    availability: Optional[Availability] = None
    auto_offline: Optional[bool] = None


class AttributeModel(Enum):
    field_0 = "0"
    field_1 = "1"


@dataclass
class ApiV1AccountsAccountIdCustomAttributeDefinitionsGetParametersQuery:
    attribute_model: AttributeModel


class Sort(Enum):
    name = "name"
    email = "email"
    phone_number = "phone_number"
    last_activity_at = "last_activity_at"
    field_name = "-name"
    field_email = "-email"
    field_phone_number = "-phone_number"
    field_last_activity_at = "-last_activity_at"


@dataclass
class ApiV1AccountsAccountIdContactsGetParametersQuery:
    sort: Optional[Sort] = None
    page: Optional[int] = 1


@dataclass
class ApiV1AccountsAccountIdContactsSearchGetParametersQuery:
    q: Optional[str] = None
    sort: Optional[Sort] = None
    page: Optional[int] = 1


@dataclass
class ApiV1AccountsAccountIdContactsFilterPostParametersQuery:
    page: Optional[int] = None


class FilterOperator(Enum):
    equal_to = "equal_to"
    not_equal_to = "not_equal_to"
    contains = "contains"
    does_not_contain = "does_not_contain"


class QueryOperator(Enum):
    AND = "AND"
    OR = "OR"


@dataclass
class ApiV1AccountsAccountIdContactsFilterPostRequest:
    attribute_key: Optional[str] = None
    filter_operator: Optional[FilterOperator] = None
    values: Optional[List[str]] = None
    query_operator: Optional[QueryOperator] = None


@dataclass
class ApiV1AccountsAccountIdContactsIdContactInboxesPostRequest:
    inbox_id: float
    source_id: Optional[str] = None


@dataclass
class ApiV1AccountsAccountIdAutomationRulesGetParametersQuery:
    page: Optional[int] = 1


class Status1(Enum):
    open = "open"
    resolved = "resolved"
    pending = "pending"
    snoozed = "snoozed"


@dataclass
class ApiV1AccountsAccountIdConversationsMetaGetParametersQuery:
    q: Optional[str] = None
    inbox_id: Optional[int] = None
    team_id: Optional[int] = None
    labels: Optional[List[str]] = None
    status: Optional[Status1] = "open"


@dataclass
class ApiV1AccountsAccountIdConversationsMetaGetResponse:
    meta: Optional[Meta1] = None


class AssigneeType(Enum):
    me = "me"
    unassigned = "unassigned"
    all = "all"
    assigned = "assigned"


@dataclass
class ApiV1AccountsAccountIdConversationsGetParametersQuery:
    q: Optional[str] = None
    inbox_id: Optional[int] = None
    team_id: Optional[int] = None
    labels: Optional[List[str]] = None
    assignee_type: Optional[AssigneeType] = "all"
    status: Optional[Status1] = "open"
    page: Optional[int] = 1


class Status3(Enum):
    open = "open"
    resolved = "resolved"
    pending = "pending"


@dataclass
class ApiV1AccountsAccountIdConversationsPostRequest:
    source_id: Optional[str] = None
    inbox_id: Optional[str] = None
    contact_id: Optional[str] = None
    additional_attributes: Optional[Dict[str, Any]] = None
    custom_attributes: Optional[Dict[str, Any]] = None
    status: Optional[Status3] = None
    assignee_id: Optional[str] = None
    team_id: Optional[str] = None


@dataclass
class ApiV1AccountsAccountIdConversationsPostResponse:
    id: Optional[float] = None
    account_id: Optional[float] = None
    inbox_id: Optional[float] = None


@dataclass
class ApiV1AccountsAccountIdConversationsFilterPostParametersQuery:
    page: Optional[int] = None


@dataclass
class ApiV1AccountsAccountIdConversationsFilterPostRequest:
    attribute_key: Optional[str] = None
    filter_operator: Optional[FilterOperator] = None
    values: Optional[List[str]] = None
    query_operator: Optional[QueryOperator] = None


@dataclass
class ApiV1AccountsAccountIdConversationsConversationIdToggleStatusPostRequest:
    status: Status3


@dataclass
class ApiV1AccountsAccountIdConversationsConversationIdAssignmentsPostRequest:
    assignee_id: Optional[float] = None
    team_id: Optional[float] = None


@dataclass
class ApiV1AccountsAccountIdConversationsConversationIdLabelsPostRequest:
    labels: Optional[List[str]] = None


class Type2(Enum):
    web_widget = "web_widget"


@dataclass
class Channel:
    type: Optional[Type2] = None
    website_url: Optional[str] = None
    welcome_title: Optional[str] = None
    welcome_tagline: Optional[str] = None
    agent_away_message: Optional[str] = None
    widget_color: Optional[str] = None


@dataclass
class ApiV1AccountsAccountIdInboxesPostRequest:
    name: Optional[str] = None
    avatar: Optional[bytes] = None
    channel: Optional[Channel] = None


@dataclass
class Channel1:
    website_url: Optional[str] = None
    welcome_title: Optional[str] = None
    welcome_tagline: Optional[str] = None
    agent_away_message: Optional[str] = None
    widget_color: Optional[str] = None


@dataclass
class ApiV1AccountsAccountIdInboxesIdPatchRequest:
    enable_auto_assignment: bool
    name: Optional[str] = None
    avatar: Optional[bytes] = None
    channel: Optional[Channel1] = None


@dataclass
class ApiV1AccountsAccountIdInboxesIdSetAgentBotPostRequest:
    agent_bot: float


@dataclass
class ApiV1AccountsAccountIdInboxMembersInboxIdDeleteRequest:
    user_ids: List[int]
    inbox_id: str = Field(alias="inbox_id_")


@dataclass
class ApiV1AccountsAccountIdInboxMembersPostRequest:
    inbox_id: str
    user_ids: List[int]


@dataclass
class ApiV1AccountsAccountIdInboxMembersPatchRequest:
    inbox_id: str
    user_ids: List[int]


@dataclass
class ApiV1AccountsAccountIdConversationsConversationIdMessagesGetResponse(GenericId, Message):
    pass


@dataclass
class ApiV1AccountsAccountIdConversationsConversationIdMessagesPostResponse(GenericId, Message):
    pass


@dataclass
class AccountsAccountIdTeamsTeamIdTeamMembersPostRequest:
    user_ids: List[int]


@dataclass
class AccountsAccountIdTeamsTeamIdTeamMembersPatchRequest:
    user_ids: List[int]


@dataclass
class AccountsAccountIdTeamsTeamIdTeamMembersDeleteRequest:
    user_ids: List[int]


class FilterType(Enum):
    conversation = "conversation"
    contact = "contact"
    report = "report"


@dataclass
class ApiV1AccountsAccountIdCustomFiltersGetParametersQuery:
    filter_type: Optional[FilterType] = None


@dataclass
class ApiV1AccountsAccountIdCustomFiltersPostParametersQuery:
    filter_type: Optional[FilterType] = None


class Metric1(Enum):
    conversations_count = "conversations_count"
    incoming_messages_count = "incoming_messages_count"
    outgoing_messages_count = "outgoing_messages_count"
    avg_first_response_time = "avg_first_response_time"
    avg_resolution_time = "avg_resolution_time"
    resolutions_count = "resolutions_count"


class Type3(Enum):
    account = "account"
    agent = "agent"
    inbox = "inbox"
    label = "label"
    team = "team"


@dataclass
class ApiV2AccountsAccountIdReportsGetParametersQuery:
    metric: Metric1
    type: Type3
    id: Optional[str] = None
    since: Optional[str] = None
    until: Optional[str] = None


@dataclass
class ApiV2AccountsAccountIdReportsGetResponse:
    value: Optional[str] = None
    timestamp: Optional[float] = None


@dataclass
class ApiV2AccountsAccountIdReportsSummaryGetParametersQuery:
    type: Type3
    id: Optional[str] = None
    since: Optional[str] = None
    until: Optional[str] = None


class Type5(Enum):
    account = "account"


@dataclass
class ApiV2AccountsAccountIdReportsConversationsGetParametersQuery:
    type: Type5


@dataclass
class ApiV2AccountsAccountIdReportsConversationsGetResponse:
    open: Optional[float] = None
    unattended: Optional[float] = None
    unassigned: Optional[float] = None


class Type6(Enum):
    agent = "agent"


@dataclass
class ApiV2AccountsAccountIdReportsConversationsGetParametersQuery1:
    type: Type6
    user_id: Optional[str] = None


@dataclass
class BadRequestError:
    description: Optional[str] = None
    errors: Optional[List[RequestError]] = None


@dataclass
class Contact:
    email: Optional[str] = None
    name: Optional[str] = None
    phone_number: Optional[str] = None
    thumbnail: Optional[str] = None
    additional_attributes: Optional[Dict[str, Any]] = None
    custom_attributes: Optional[Dict[str, Any]] = None
    contact_inboxes: Optional[List[ContactInboxes]] = None


@dataclass
class Conversation:
    id: Optional[float] = None
    messages: Optional[List[Message]] = None
    account_id: Optional[float] = None
    inbox_id: Optional[float] = None
    status: Optional[Status] = None
    timestamp: Optional[str] = None
    contact_last_seen_at: Optional[str] = None
    agent_last_seen_at: Optional[str] = None
    unread_count: Optional[float] = None
    additional_attributes: Optional[Dict[str, Any]] = None
    custom_attributes: Optional[Dict[str, Any]] = None


@dataclass
class User:
    id: Optional[float] = None
    uid: Optional[str] = None
    name: Optional[str] = None
    available_name: Optional[str] = None
    display_name: Optional[str] = None
    email: Optional[str] = None
    account_id: Optional[float] = None
    role: Optional[Role] = None
    confirmed: Optional[bool] = None
    custom_attributes: Optional[Dict[str, Any]] = None
    accounts: Optional[List[Account]] = None


@dataclass
class ExtendedContact(Contact):
    id: Optional[float] = None
    availability_status: Optional[AvailabilityStatus1] = None


@dataclass
class ContactBase(GenericId, Contact):
    pass


@dataclass
class ContactListItem(GenericId, Contact):
    pass


ContactList = List[ContactListItem]


@dataclass
class Meta:
    sender: Optional[Sender] = None
    assignee: Optional[User] = None


@dataclass
class ContactConversation(Conversation):
    meta: Optional[Meta] = None
    display_id: Optional[float] = None


ContactConversations = List[ContactConversation]


@dataclass
class Meta2:
    sender: Optional[Sender] = None
    assignee: Optional[User] = None


@dataclass
class PayloadItem(GenericId, Conversation):
    meta: Optional[Meta2] = None


@dataclass
class Data:
    meta: Optional[Meta1] = None
    payload: Optional[List[PayloadItem]] = None


@dataclass
class ConversationList:
    data: Optional[Data] = None


@dataclass
class Meta3:
    sender: Optional[Sender] = None
    assignee: Optional[User] = None


@dataclass
class ConversationShow(GenericId, Conversation):
    meta: Optional[Meta3] = None


@dataclass
class ApiV1AccountsAccountIdContactsSearchGetResponse:
    payload: Optional[ContactList] = None



import re
from typing import Any, Optional, Union, Type
from dataclasses import dataclass
from chatwoot_client.http import HttpClient
from chatwoot_client.definitions.actions import *


class Actions:
    client: HttpClient

    def __init__(self, client: HttpClient):
        self.client = client

    def __getitem__(self, item):
        return getattr(self, item)


@dataclass
class Action(Actions):
    method: str
    url: str
    query: Optional[Union[Type, Any]] = None
    schema_: Optional[Union[Type, Any]] = None


def action_factory(client: HttpClient, method: str, url: str, query=None, schema_=None) -> Action:
    """Factory function to create a default Action instance."""
    print(f"method: {method}, url: {url}, query: {query}, schema_: {schema_}")

    def run_action(**kwargs):
        try:
            fmt_url = url.format(**kwargs)
        except KeyError:
            url_params = re.findall("{(.*?)}", url)
            provided_params = list(kwargs.keys())
            raise ValueError(f"{method} {url} needs parameters: {url_params}, but where provided: {provided_params}")
        print(fmt_url)

    return run_action
    # return Action(method=method, url=url, query=query, schema_=schema_)



""" 
Schemas for the webhook events.

Only implemented MessageCreatedEvent for now. Feel free to add more as needed.
"""

from __future__ import annotations
from dataclasses import dataclass
from typing import Any, List


@dataclass
class MessageCreatedEvent:
    account: Account
    additional_attributes: Any
    content_attributes: Any
    content_type: str
    content: str | None
    conversation: Conversation
    created_at: str
    id: int
    inbox: Inbox
    message_type: str
    private: bool
    sender: Sender
    source_id: Any | None
    attachments: List[Attachment] | None
    event: str


@dataclass
class Conversation:
    additional_attributes: Any
    can_reply: bool
    channel: str
    contact_inbox: ContactInbox
    id: int
    inbox_id: int
    messages: List[Message]
    labels: List[Any]
    meta: Meta
    status: str
    custom_attributes: Any
    snoozed_until: Any | None
    unread_count: int
    first_reply_created_at: None
    priority: Any | None
    waiting_since: int
    agent_last_seen_at: int
    contact_last_seen_at: int
    timestamp: int
    created_at: int


@dataclass
class ContactInbox:
    id: int
    contact_id: int
    inbox_id: int
    source_id: str
    created_at: str
    updated_at: str
    hmac_verified: bool
    pubsub_token: str


@dataclass
class Message:
    id: int
    content: str | None
    account_id: int
    inbox_id: int
    conversation_id: int
    message_type: int
    created_at: int
    updated_at: str
    private: bool
    status: str
    source_id: Any | None
    content_type: str
    content_attributes: Any
    sender_type: str
    sender_id: int
    external_source_ids: Any
    additional_attributes: Any
    processed_message_content: str | None
    sentiment: Any
    conversation: MessageConversation
    attachments: List[Attachment] | None
    sender: Sender


@dataclass
class MessageConversation:
    assignee_id: Any | None
    unread_count: int
    last_activity_at: int
    contact_inbox: ContactInbox


@dataclass
class ContactInbox:
    source_id: str


@dataclass
class Attachment:
    id: int
    message_id: int
    file_type: str
    account_id: int
    extension: Any | None
    data_url: str
    thumb_url: str
    file_size: int


@dataclass
class Meta:
    sender: Sender
    assignee: None
    team: None
    hmac_verified: bool


@dataclass
class Account:
    id: int
    name: str


@dataclass
class Inbox:
    id: int
    name: str


@dataclass
class Sender:
    account: Account | None
    additional_attributes: Any
    avatar: str | None
    custom_attributes: Any
    email: None
    id: int
    identifier: str
    name: str
    phone_number: str
    thumbnail: str
    type: str | None



""" All actions for resources are defined here. """

from chatwoot_client.action import Actions

from .schemas.input_schemas import *


class AccountsActions(Actions):
    def create(self, payload: AccountCreateUpdatePayload):
        return self.client.post("platform/api/v1/accounts", data=payload)

    def get(self, account_id: int):
        return self.client.get(f"platform/api/v1/accounts/{account_id}")

    def update(self, account_id: int, payload: AccountCreateUpdatePayload):
        return self.client.patch(f"platform/api/v1/accounts/{account_id}", data=payload)

    def delete(self, account_id: int):
        return self.client.delete(f"platform/api/v1/accounts/{account_id}")


class AccountUsersActions(Actions):
    def list(self, account_id: int):
        return self.client.get(f"platform/api/v1/accounts/{account_id}/account_users")

    def create(self, account_id: int, payload: PlatformApiV1AccountsAccountIdAccountUsersPostRequest):
        return self.client.post(f"platform/api/v1/accounts/{account_id}/account_users", data=payload)

    def delete(self, account_id: int, account_user_id: int):
        return self.client.delete(f"platform/api/v1/accounts/{account_id}/account_users/{account_user_id}")


class AgentBotsActions(Actions):
    def list(self):
        return self.client.get("platform/api/v1/agent_bots")

    def create(self, payload: AgentBotCreateUpdatePayload):
        return self.client.post("platform/api/v1/agent_bots", data=payload)

    def get(self, id: int):
        return self.client.get(f"platform/api/v1/agent_bots/{id}")

    def update(self, id: int, payload: AgentBotCreateUpdatePayload):
        return self.client.patch(f"platform/api/v1/agent_bots/{id}", data=payload)

    def delete(self, id: int):
        return self.client.delete(f"platform/api/v1/agent_bots/{id}")


class UsersActions(Actions):
    def list(self):
        return self.client.get("platform/api/v1/users")

    def create(self, payload: UserCreateUpdatePayload):
        return self.client.post("platform/api/v1/users", data=payload)

    def get(self, id: int):
        return self.client.get(f"platform/api/v1/users/{id}")

    def update(self, id: int, payload: UserCreateUpdatePayload):
        return self.client.patch(f"platform/api/v1/users/{id}", data=payload)

    def delete(self, id: int):
        return self.client.delete(f"platform/api/v1/users/{id}")

    def get_sso_link(self, id: int):
        return self.client.get(f"platform/api/v1/users/{id}/login")


class AccountAgentBotsActions(Actions):
    def list(self, account_id: int):
        return self.client.get(f"api/v1/accounts/{account_id}/agent_bots")

    def create(self, account_id: int, payload: AgentBotCreateUpdatePayload):
        return self.client.post(f"api/v1/accounts/{account_id}/agent_bots", data=payload)

    def delete(self, account_id: int, id: int):
        return self.client.delete(f"api/v1/accounts/{account_id}/agent_bots/{id}")

    def get(self, account_id: int, id: int):
        return self.client.get(f"api/v1/accounts/{account_id}/agent_bots/{id}")

    def update(self, account_id: int, id: int, payload: AgentBotCreateUpdatePayload):
        return self.client.patch(f"api/v1/accounts/{account_id}/agent_bots/{id}", data=payload)


class AgentsActions(Actions):
    def list(self, account_id: int):
        return self.client.get(f"api/v1/accounts/{account_id}/agents")

    def create(self, account_id: int, payload: ApiV1AccountsAccountIdAgentsPostRequest):
        return self.client.post(f"api/v1/accounts/{account_id}/agents", data=payload)

    def update(self, account_id: int, id: int, payload: ApiV1AccountsAccountIdAgentsIdPatchRequest):
        return self.client.patch(f"api/v1/accounts/{account_id}/agents/{id}", data=payload)

    def delete(self, account_id: int, id: int):
        return self.client.delete(f"api/v1/accounts/{account_id}/agents/{id}")


class CannedResponsesActions(Actions):
    def list(self, account_id: int):
        return self.client.get(f"api/v1/accounts/{account_id}/canned_responses")

    def create(self, account_id: int, payload: CannedResponseCreateUpdatePayload):
        return self.client.post(f"api/v1/accounts/{account_id}/canned_responses", data=payload)

    def delete(self, account_id: int, id: int):
        return self.client.delete(f"api/v1/accounts/{account_id}/canned_responses/{id}")


class ContactsActions(Actions):
    def list(self, account_id: int, query: ApiV1AccountsAccountIdContactsGetParametersQuery):
        return self.client.get(f"api/v1/accounts/{account_id}/contacts", query=query)

    def create(self, account_id: int, payload: ContactCreate):
        return self.client.post(f"api/v1/accounts/{account_id}/contacts", data=payload)

    def update(self, account_id: int, id: int, payload: ContactUpdate):
        return self.client.patch(f"api/v1/accounts/{account_id}/contacts/{id}", data=payload)

    def delete(self, account_id: int, id: int):
        return self.client.delete(f"api/v1/accounts/{account_id}/contacts/{id}")

    def get(self, account_id: int, id: int):
        return self.client.get(f"api/v1/accounts/{account_id}/contacts/{id}")

    def get_conversations(self, account_id: int, id: int):
        return self.client.get(f"api/v1/accounts/{account_id}/contacts/{id}/conversations")

    def search(self, account_id: int, query: ApiV1AccountsAccountIdContactsSearchGetParametersQuery):
        return self.client.get(f"api/v1/accounts/{account_id}/contacts/search", query=query)

    def filter(
        self,
        account_id: int,
        query: ApiV1AccountsAccountIdContactsFilterPostParametersQuery,
        payload: ApiV1AccountsAccountIdContactsFilterPostRequest,
    ):
        return self.client.post(f"api/v1/accounts/{account_id}/contacts/filter", query=query, data=payload)


class ConversationAssignmentActions(Actions):
    def assign(
        self,
        account_id: int,
        conversation_id: int,
        payload: ApiV1AccountsAccountIdConversationsConversationIdAssignmentsPostRequest,
    ):
        return self.client.post(
            f"api/v1/accounts/{account_id}/conversations/{conversation_id}/assignments", data=payload
        )


class ConversationLabelsActions(Actions):
    def list(self, account_id: int, conversation_id: int):
        return self.client.get(f"api/v1/accounts/{account_id}/conversations/{conversation_id}/labels")

    def create(
        self,
        account_id: int,
        conversation_id: int,
        payload: ApiV1AccountsAccountIdConversationsConversationIdLabelsPostRequest,
    ):
        return self.client.post(f"api/v1/accounts/{account_id}/conversations/{conversation_id}/labels", data=payload)


class ConversationsActions(Actions):
    def get_meta(self, account_id: int, query: ApiV1AccountsAccountIdConversationsMetaGetParametersQuery):
        return self.client.get(f"api/v1/accounts/{account_id}/conversations/meta", query=query)

    def list(self, account_id: int, query: ApiV1AccountsAccountIdConversationsGetParametersQuery):
        return self.client.get(f"api/v1/accounts/{account_id}/conversations", query=query)

    def create(self, account_id: int, payload: ApiV1AccountsAccountIdConversationsPostRequest):
        return self.client.post(f"api/v1/accounts/{account_id}/conversations", data=payload)

    def get(self, account_id: int, conversation_id: int):
        return self.client.get(f"api/v1/accounts/{account_id}/conversations/{conversation_id}")

    def filter(
        self,
        account_id: int,
        query: ApiV1AccountsAccountIdConversationsFilterPostParametersQuery,
        payload: ApiV1AccountsAccountIdConversationsFilterPostRequest,
    ):
        return self.client.post(f"api/v1/accounts/{account_id}/conversations/filter", query=query, data=payload)

    def toggle_status(self, account_id: int, conversation_id: int):
        return self.client.post(f"api/v1/accounts/{account_id}/conversations/{conversation_id}/toggle_status")


class CustomAttributesActions(Actions):
    def list(self, account_id: int, query: ApiV1AccountsAccountIdCustomAttributeDefinitionsGetParametersQuery):
        return self.client.get(f"api/v1/accounts/{account_id}/custom_attribute_definitions", query=query)

    def create(self, account_id: int, payload: CustomAttributeCreateUpdatePayload):
        return self.client.post(f"api/v1/accounts/{account_id}/custom_attribute_definitions", data=payload)

    def get(self, account_id: int, id: int):
        return self.client.get(f"api/v1/accounts/{account_id}/custom_attribute_definitions/{id}")

    def update(self, account_id: int, id: int, payload: CustomAttributeCreateUpdatePayload):
        return self.client.patch(f"api/v1/accounts/{account_id}/custom_attribute_definitions/{id}", data=payload)

    def delete(self, account_id: int, id: int):
        return self.client.delete(f"api/v1/accounts/{account_id}/custom_attribute_definitions/{id}")


class CustomFiltersActions(Actions):
    def list(self, account_id: int, query: ApiV1AccountsAccountIdCustomFiltersGetParametersQuery):
        return self.client.get(f"api/v1/accounts/{account_id}/custom_filters", query=query)

    def create(
        self,
        account_id: int,
        query: ApiV1AccountsAccountIdCustomFiltersPostParametersQuery,
        payload: CustomFilterCreateUpdatePayload,
    ):
        return self.client.post(f"api/v1/accounts/{account_id}/custom_filters", query=query, data=payload)

    def get(self, account_id: int, custom_filter_id: int):
        return self.client.get(f"api/v1/accounts/{account_id}/custom_filters/{custom_filter_id}")

    def update(self, account_id: int, custom_filter_id: int, payload: CustomFilterCreateUpdatePayload):
        return self.client.patch(f"api/v1/accounts/{account_id}/custom_filters/{custom_filter_id}", data=payload)

    def delete(self, account_id: int, custom_filter_id: int):
        return self.client.delete(f"api/v1/accounts/{account_id}/custom_filters/{custom_filter_id}")


class InboxesActions(Actions):
    def list(self, account_id: int):
        return self.client.get(f"api/v1/accounts/{account_id}/inboxes")

    def create(self, account_id: int, payload: ApiV1AccountsAccountIdInboxesPostRequest):
        return self.client.post(f"api/v1/accounts/{account_id}/inboxes", data=payload)

    def get(self, account_id: int, id: int):
        return self.client.get(f"api/v1/accounts/{account_id}/inboxes/{id}")

    def update(self, account_id: int, id: int, payload: ApiV1AccountsAccountIdInboxesIdPatchRequest):
        return self.client.patch(f"api/v1/accounts/{account_id}/inboxes/{id}", data=payload)

    def delete(self, account_id: int, id: int):
        return self.client.delete(f"api/v1/accounts/{account_id}/inboxes/{id}")

    def get_associated_agent_bot(self, account_id: int, id: int):
        return self.client.get(f"api/v1/accounts/{account_id}/inboxes/{id}/agent_bot")

    def set_agent_bot(self, account_id: int, id: int, payload: ApiV1AccountsAccountIdInboxesIdSetAgentBotPostRequest):
        return self.client.post(f"api/v1/accounts/{account_id}/inboxes/{id}/set_agent_bot", data=payload)

    def list_agents(self, account_id: int, inbox_id: int):
        return self.client.get(f"api/v1/accounts/{account_id}/inbox_members/{inbox_id}")

    def delete_agent(
        self, account_id: int, inbox_id: int, payload: ApiV1AccountsAccountIdInboxMembersInboxIdDeleteRequest
    ):
        return self.client.delete(f"api/v1/accounts/{account_id}/inbox_members/{inbox_id}", data=payload)

    def add_agent(self, account_id: int, payload: ApiV1AccountsAccountIdInboxMembersPostRequest):
        return self.client.post(f"api/v1/accounts/{account_id}/inbox_members", data=payload)

    def update_agent(self, account_id: int, payload: ApiV1AccountsAccountIdInboxMembersPatchRequest):
        return self.client.patch(f"api/v1/accounts/{account_id}/inbox_members", data=payload)


class IntegrationsActions(Actions):
    def list(self, account_id: int):
        return self.client.get(f"api/v1/accounts/{account_id}/integrations/apps")

    def create(self, account_id: int, payload: IntegrationsHookCreatePayload):
        return self.client.post(f"api/v1/accounts/{account_id}/integrations/hooks", data=payload)

    def update(self, account_id: int, hook_id: int, payload: IntegrationsHookUpdatePayload):
        return self.client.patch(f"api/v1/accounts/{account_id}/integrations/hooks/{hook_id}", data=payload)

    def delete(self, account_id: int, hook_id: int):
        return self.client.delete(f"api/v1/accounts/{account_id}/integrations/hooks/{hook_id}")


class MessagesActions(Actions):
    def list(self, account_id: int, conversation_id: int):
        return self.client.get(f"api/v1/accounts/{account_id}/conversations/{conversation_id}/messages")

    def create(self, account_id: int, conversation_id: int, payload: ConversationMessageCreate):
        return self.client.post(f"api/v1/accounts/{account_id}/conversations/{conversation_id}/messages", data=payload)

    def delete(self, account_id: int, conversation_id: int, id: int):
        return self.client.delete(f"api/v1/accounts/{account_id}/conversations/{conversation_id}/messages/{id}")

    def create_attachment(self, account_id: int, conversation_id: int, payload: ConversationMessageAttachmentCreate):
        return self.client.post(f"api/v1/accounts/{account_id}/conversations/{conversation_id}/messages", data=payload)


class ProfileActions(Actions):
    def get(self, account_id: int):
        return self.client.get(f"api/v1/accounts/{account_id}/profile")


class ReportsActions(Actions):
    def get_accounts_report(self, account_id: int, query: ApiV2AccountsAccountIdReportsGetParametersQuery):
        return self.client.get(f"api/v1/accounts/{account_id}/reports", query=query)

    def get_account_report_summary(
        self, account_id: int, query: ApiV2AccountsAccountIdReportsSummaryGetParametersQuery
    ):
        return self.client.get(f"api/v1/accounts/{account_id}/reports/summary", query=query)

    def get_conversation_metrics_for_account(
        self, account_id: int, query: ApiV2AccountsAccountIdReportsConversationsGetParametersQuery
    ):
        return self.client.get(f"api/v1/accounts/{account_id}/reports/conversations", query=query)

    def get_conversation_metrics_for_agent(
        self, account_id: int, query: ApiV2AccountsAccountIdReportsConversationsGetParametersQuery1
    ):
        return self.client.get(f"api/v1/accounts/{account_id}/reports/conversations", query=query)


class TeamsActions(Actions):
    def list(self, account_id: int):
        return self.client.get(f"api/v1/accounts/{account_id}/teams")

    def create(self, account_id: int, payload: TeamCreateUpdatePayload):
        return self.client.post(f"api/v1/accounts/{account_id}/teams", data=payload)

    def get(self, account_id: int, team_id: int):
        return self.client.get(f"api/v1/accounts/{account_id}/teams/{team_id}")

    def update(self, account_id: int, team_id: int, payload: TeamCreateUpdatePayload):
        return self.client.patch(f"api/v1/accounts/{account_id}/teams/{team_id}", data=payload)

    def delete(self, account_id: int, team_id: int):
        return self.client.delete(f"api/v1/accounts/{account_id}/teams/{team_id}")

    def list_agents(self, account_id: int, team_id: int):
        return self.client.get(f"api/v1/accounts/{account_id}/teams/{team_id}/team_members")

    def delete_agent(
        self, account_id: int, team_id: int, payload: AccountsAccountIdTeamsTeamIdTeamMembersDeleteRequest
    ):
        return self.client.delete(f"api/v1/accounts/{account_id}/teams/{team_id}/team_members", data=payload)

    def add_agent(self, account_id: int, team_id: int, payload: AccountsAccountIdTeamsTeamIdTeamMembersPostRequest):
        return self.client.post(f"api/v1/accounts/{account_id}/teams/{team_id}/team_members", data=payload)

    def update_agent(self, account_id: int, team_id: int, payload: AccountsAccountIdTeamsTeamIdTeamMembersPatchRequest):
        return self.client.patch(f"api/v1/accounts/{account_id}/teams/{team_id}/team_members", data=payload)


class WebhooksActions(Actions):
    def list(self, account_id: int):
        return self.client.get(f"api/v1/accounts/{account_id}/webhooks")

    def create(self, account_id: int, payload: WebhookCreateUpdatePayload):
        return self.client.post(f"api/v1/accounts/{account_id}/webhooks", data=payload)

    def update(self, account_id: int, webhook_id: int, payload: WebhookCreateUpdatePayload):
        return self.client.patch(f"api/v1/accounts/{account_id}/webhooks/{webhook_id}", data=payload)

    def delete(self, account_id: int, webhook_id: int):
        return self.client.delete(f"api/v1/accounts/{account_id}/webhooks/{webhook_id}")


class AutomationRuleActions(Actions):
    def list(self, account_id: int, query: ApiV1AccountsAccountIdAutomationRulesGetParametersQuery):
        return self.client.get(f"api/v1/accounts/{account_id}/automation_rules", query=query)

    def create(self, account_id: int, payload: AutomationRuleCreateUpdatePayload):
        return self.client.post(f"api/v1/accounts/{account_id}/automation_rules", data=payload)

    def get(self, account_id: int, id: int):
        return self.client.get(f"api/v1/accounts/{account_id}/automation_rules/{id}")

    def update(self, account_id: int, id: int, payload: AutomationRuleCreateUpdatePayload):
        return self.client.patch(f"api/v1/accounts/{account_id}/automation_rules/{id}", data=payload)

    def delete(self, account_id: int, id: int):
        return self.client.delete(f"api/v1/accounts/{account_id}/automation_rules/{id}")


class ClientContactsActions(Actions):
    def create(self, inbox_identifier: int, payload: PublicContactCreateUpdatePayload):
        return self.client.post(f"public/api/v1/inboxes/{inbox_identifier}/contacts", data=payload)

    def get(self, inbox_identifier: int, contact_identifier: int):
        return self.client.get(f"public/api/v1/inboxes/{inbox_identifier}/contacts/{contact_identifier}")

    def update(self, inbox_identifier: int, contact_identifier: int, payload: PublicContactCreateUpdatePayload):
        return self.client.patch(
            f"public/api/v1/inboxes/{inbox_identifier}/contacts/{contact_identifier}", data=payload
        )


class ClientConversationsActions(Actions):
    def list(self, inbox_identifier: int, contact_identifier: int):
        return self.client.get(f"public/api/v1/inboxes/{inbox_identifier}/contacts/{contact_identifier}/conversations")

    def create(self, inbox_identifier: int, contact_identifier: int):
        return self.client.post(f"public/api/v1/inboxes/{inbox_identifier}/contacts/{contact_identifier}/conversations")


class ClientMessagesActions(Actions):
    def list(self, inbox_identifier: int, contact_identifier: int, conversation_id: int):
        return self.client.get(
            f"public/api/v1/inboxes/{inbox_identifier}/contacts/{contact_identifier}/conversations/{conversation_id}/messages"
        )

    def create(
        self,
        inbox_identifier: int,
        contact_identifier: int,
        conversation_id: int,
        payload: PublicMessageCreatePayload,
    ):
        return self.client.post(
            f"public/api/v1/inboxes/{inbox_identifier}/contacts/{contact_identifier}/conversations/{conversation_id}/messages",
            data=payload,
        )

    def update(
        self,
        inbox_identifier: int,
        contact_identifier: int,
        conversation_id: int,
        message_id: int,
        payload: PublicMessageUpdatePayload,
    ):
        return self.client.patch(
            f"public/api/v1/inboxes/{inbox_identifier}/contacts/{contact_identifier}/conversations/{conversation_id}/messages/{message_id}",
            data=payload,
        )



import httpx


class HttpClient:
    def __init__(self, api_url, api_token):
        self.api_token = api_token
        self.api_url = api_url
        self.headers = {
            "api_access_token": f"{api_token}",
            "Content-Type": "application/json",
        }

    def _request(self, method, url, query=None, data=None):
        with httpx.Client() as client:
            response = client.request(
                method,
                f"{self.api_url}{url}",
                headers=self.headers,
                params=query,
                json=data,
            )
            response.raise_for_status()
            return response.json()

    def get(self, url, query=None):
        return self._request("GET", url, query)

    def post(self, url, data=None):
        return self._request("POST", url, data=data)

    def put(self, url, data=None):
        return self._request("PUT", url, data=data)

    def delete(self, url):
        return self._request("DELETE", url)

    def patch(self, url, data=None):
        return self._request("PATCH", url, data=data)



from chatwoot_client.definitions.actions import *
from chatwoot_client.http import HttpClient
from chatwoot_client.definitions.schemas import input_schemas
from chatwoot_client.definitions.schemas import webhooks_events


class ChatwootClient:
    accounts: AccountsActions
    account_users: AccountUsersActions
    agent_bots: AgentBotsActions
    users: UsersActions
    account_agent_bots: AccountAgentBotsActions
    agents: AgentsActions
    canned_responses: CannedResponsesActions
    contacts: ContactsActions
    conversation_assignment: ConversationAssignmentActions
    conversation_labels: ConversationLabelsActions
    conversations: ConversationsActions
    custom_attributes: CustomAttributesActions
    custom_filters: CustomFiltersActions
    inboxes: InboxesActions
    integrations: IntegrationsActions
    messages: MessagesActions
    profile: ProfileActions
    reports: ReportsActions
    teams: TeamsActions
    webhooks: WebhooksActions
    automation_rules: AutomationRuleActions
    client_contacts: ClientContactsActions
    client_conversations: ClientConversationsActions
    client_messages: ClientMessagesActions

    def __init__(self, url, access_token):
        self.client = HttpClient(url, access_token)

        self.accounts = AccountsActions(self.client)
        self.account_users = AccountUsersActions(self.client)
        self.agent_bots = AgentBotsActions(self.client)
        self.users = UsersActions(self.client)
        self.account_agent_bots = AccountAgentBotsActions(self.client)
        self.agents = AgentsActions(self.client)
        self.canned_responses = CannedResponsesActions(self.client)
        self.contacts = ContactsActions(self.client)
        self.conversation_assignment = ConversationAssignmentActions(self.client)
        self.conversation_labels = ConversationLabelsActions(self.client)
        self.conversations = ConversationsActions(self.client)
        self.custom_attributes = CustomAttributesActions(self.client)
        self.custom_filters = CustomFiltersActions(self.client)
        self.inboxes = InboxesActions(self.client)
        self.integrations = IntegrationsActions(self.client)
        self.messages = MessagesActions(self.client)
        self.profile = ProfileActions(self.client)
        self.reports = ReportsActions(self.client)
        self.teams = TeamsActions(self.client)
        self.webhooks = WebhooksActions(self.client)
        self.automation_rules = AutomationRuleActions(self.client)
        self.client_contacts = ClientContactsActions(self.client)
        self.client_conversations = ClientConversationsActions(self.client)
        self.client_messages = ClientMessagesActions(self.client)



"""
This file is just for testing. It will not be executed in the package use.
"""

from dotenv import load_dotenv

load_dotenv()

import os
from . import ChatwootClient

chatwoot = ChatwootClient(os.getenv("CHATWOOT_URL"), os.getenv("CHATWOOT_USER_TOKEN"))

response = chatwoot.agents.list(account_id=os.getenv("CHATWOOT_ACCOUNT_ID"))

print(response)
